@@ -43,57 +43,59 @@ namespace aria2 {
 
 AbstractBtMessage::AbstractBtMessage(uint8_t id, const std::string& name):
   BtMessage(id),
-  sendingInProgress(false),
-  invalidate(false),
-  uploading(false),
-  cuid(0),
-  _name(name),
-  _metadataGetMode(false),
-  logger(LogFactory::getInstance())
+  sendingInProgress_(false),
+  invalidate_(false),
+  uploading_(false),
+  cuid_(0),
+  name_(name),
+  metadataGetMode_(false),
+  logger_(LogFactory::getInstance())
 {}
 
 AbstractBtMessage::~AbstractBtMessage() {}
 
 void AbstractBtMessage::setPeer(const SharedHandle<Peer>& peer)
 {
-  this->peer = peer;
+  peer_ = peer;
 }
 
 void AbstractBtMessage::validate()
 {
-  if(validator.get()) {
-    validator->validate();
+  if(!validator_.isNull()) {
+    validator_->validate();
   }
 }
 
 void
 AbstractBtMessage::setBtMessageValidator(const SharedHandle<BtMessageValidator>& validator) {
-  this->validator = validator;
+  validator_ = validator;
 }
 
-void AbstractBtMessage::setPieceStorage(const SharedHandle<PieceStorage>& pieceStorage)
+void AbstractBtMessage::setPieceStorage
+(const SharedHandle<PieceStorage>& pieceStorage)
 {
-  this->pieceStorage = pieceStorage;
+  pieceStorage_ = pieceStorage;
 }
 
-void AbstractBtMessage::setBtMessageDispatcher(const WeakHandle<BtMessageDispatcher>& dispatcher)
+void AbstractBtMessage::setBtMessageDispatcher
+(const WeakHandle<BtMessageDispatcher>& dispatcher)
 {
-  this->dispatcher = dispatcher;
+  dispatcher_ = dispatcher;
 }
 
 void AbstractBtMessage::setPeerConnection(const WeakHandle<PeerConnection>& peerConnection)
 {
-  this->peerConnection = peerConnection;
+  peerConnection_ = peerConnection;
 }
 
 void AbstractBtMessage::setBtMessageFactory(const WeakHandle<BtMessageFactory>& factory)
 {
-  this->messageFactory = factory;
+  messageFactory_ = factory;
 }
 
 void AbstractBtMessage::setBtRequestFactory(const WeakHandle<BtRequestFactory>& factory)
 {
-  this->requestFactory = factory;
+  requestFactory_ = factory;
 }
 
 } // namespace aria2
