@@ -68,6 +68,7 @@
 #include "NameResolver.h"
 #include "ServerStatMan.h"
 #include "FileAllocationEntry.h"
+#include "uri.h"
 #ifdef ENABLE_MESSAGE_DIGEST
 # include "ChecksumCheckIntegrityEntry.h"
 #endif // ENABLE_MESSAGE_DIGEST
@@ -242,12 +243,29 @@ bool AbstractCommand::execute() {
     } else {
       if(checkPoint_.difference(global::wallclock) >= timeout_) {
         // timeout triggers ServerStat error state.
-
         SharedHandle<ServerStat> ss =
           e_->getRequestGroupMan()->getOrCreateServerStat(req_->getHost(),
                                                           req_->getProtocol());
         ss->setError();
-
+        // Purging IP address cache to renew IP address.
+        if(getLogger()->debug()) {
+          getLogger()->debug("CUID#%s - Marking IP address %s as bad",
+                             util::itos(getCuid()).c_str(),
+                             req_->getConnectedAddr().c_str());
+        }
+        e_->markBadIPAddress(req_->getConnectedHostname(),
+                             req_->getConnectedAddr(),
+                             req_->getConnectedPort());
+        if(e_->findCachedIPAddress
+           (req_->getConnectedHostname(), req_->getConnectedPort()).empty()) {
+          if(getLogger()->debug()) {
+            getLogger()->debug("CUID#%s - All IP addresses were marked bad."
+                               " Removing Entry.",
+                               util::itos(getCuid()).c_str());
+          }
+          e_->removeCachedIPAddress
+            (req_->getConnectedHostname(), req_->getConnectedPort());
+        }
         throw DL_RETRY_EX2(EX_TIME_OUT, downloadresultcode::TIME_OUT);
       }
       e_->addCommand(this);
@@ -374,9 +392,6 @@ bool AbstractCommand::prepareForRetry(time_t wait) {
 
 void AbstractCommand::onAbort() {
   if(!req_.isNull()) {
-    // TODO This might be a problem if the failure is caused by proxy.
-    e_->getRequestGroupMan()->getOrCreateServerStat
-      (req_->getHost(), req_->getProtocol())->setError();
     fileEntry_->removeIdenticalURI(req_->getUri());
     fileEntry_->removeRequest(req_);
   }
@@ -408,9 +423,9 @@ void AbstractCommand::onAbort() {
             ("CUID#%s - Gathering URIs that has CANNOT_RESUME error",
              util::itos(getCuid()).c_str());
         }
-        // Set PREF_ALWAYS_RESUME to V_TRUE to avoid repeating this
+        // Set PREF_ALWAYS_RESUME to A2_V_TRUE to avoid repeating this
         // process.
-        getOption()->put(PREF_ALWAYS_RESUME, V_TRUE);
+        getOption()->put(PREF_ALWAYS_RESUME, A2_V_TRUE);
         std::deque<URIResult> res;
         fileEntry_->extractURIResult(res, downloadresultcode::CANNOT_RESUME);
         if(!res.empty()) {
@@ -539,7 +554,8 @@ static bool isProxyRequest
 (const std::string& protocol, const SharedHandle<Option>& option)
 {
   const std::string& proxyUri = getProxyUri(protocol, option);
-  return !proxyUri.empty() && Request().setUri(proxyUri);
+  uri::UriStruct us;
+  return !proxyUri.empty() && uri::parse(us, proxyUri);
 }
 
 namespace {
@@ -758,34 +774,12 @@ std::string AbstractCommand::resolveHostname
   return ipaddr;
 }
 
-// nextCommand is going to be managed by CheckIntegrityEntry which is
-// created in side this function. Don't release nextCommand after this
-// function call.
-void AbstractCommand::prepareForNextAction(Command* nextCommand)
+void AbstractCommand::prepareForNextAction
+(const SharedHandle<CheckIntegrityEntry>& checkEntry)
 {
-#ifdef ENABLE_MESSAGE_DIGEST
-  if(requestGroup_->downloadFinished() &&
-     getDownloadContext()->isChecksumVerificationNeeded()) {
-    if(getLogger()->info()) {
-      getLogger()->info(MSG_HASH_CHECK_NOT_DONE);
-    }
-    SharedHandle<CheckIntegrityEntry> entry
-      (new ChecksumCheckIntegrityEntry(requestGroup_));
-    if(entry->isValidationReady()) {
-      delete nextCommand;
-      entry->initValidator();
-      entry->cutTrailingGarbage();
-      e_->getCheckIntegrityMan()->pushEntry(entry);
-      return;
-    }
-  }
-#endif // ENABLE_MESSAGE_DIGEST
-  SharedHandle<CheckIntegrityEntry> entry
-    (new StreamCheckIntegrityEntry(requestGroup_, nextCommand));
-
   std::vector<Command*>* commands = new std::vector<Command*>();
   auto_delete_container<std::vector<Command*> > commandsDel(commands);
-  requestGroup_->processCheckIntegrityEntry(*commands, entry, e_);
+  requestGroup_->processCheckIntegrityEntry(*commands, checkEntry, e_);
   e_->addCommand(*commands);
   commands->clear();
   e_->setNoWait(true);
