@@ -174,6 +174,11 @@ protected:
    */
   void setWriteCheckSocketIf(const SharedHandle<SocketCore>& socket, bool pred);
 
+  time_t getTimeout() const
+  {
+    return timeout_;
+  }
+
   void setTimeout(time_t timeout) { timeout_ = timeout; }
 
   void prepareForNextAction
@@ -222,6 +227,11 @@ protected:
   {
     return requestGroup_->getPieceStorage();
   }
+
+  Timer& getCheckPoint()
+  {
+    return checkPoint_;
+  }
 public:
   AbstractCommand
   (cuid_t cuid, const SharedHandle<Request>& req,
