@@ -81,7 +81,13 @@ bool DHTEntryPointNameResolveCommand::execute()
   }
 #ifdef ENABLE_ASYNC_DNS
   if(resolver_.isNull()) {
-    resolver_.reset(new AsyncNameResolver());
+    int family;
+    if(e_->getOption()->getAsBool(PREF_ENABLE_ASYNC_DNS6)) {
+      family = AF_UNSPEC;
+    } else {
+      family = AF_INET;
+    }
+    resolver_.reset(new AsyncNameResolver(family));
   }
 #endif // ENABLE_ASYNC_DNS
   try {
@@ -90,7 +96,12 @@ bool DHTEntryPointNameResolveCommand::execute()
       while(!entryPoints_.empty()) {
         std::string hostname = entryPoints_.front().first;
         try {
-          if(resolveHostname(hostname, resolver_)) {
+          if(util::isNumericHost(hostname)) {
+            std::pair<std::string, uint16_t> p
+              (hostname, entryPoints_.front().second);
+            resolvedEntryPoints_.push_back(p);
+            addPingTask(p);
+          } else if(resolveHostname(hostname, resolver_)) {
             hostname = resolver_->getResolvedAddresses().front();
             std::pair<std::string, uint16_t> p(hostname,
                                                entryPoints_.front().second);
