@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -39,7 +39,8 @@
 
 #include  <limits.h>
 
-#include "TimeA2.h"
+#include "TimerA2.h"
+#include "Command.h"
 
 namespace aria2 {
 
@@ -97,50 +98,52 @@ public:
 
 class DefaultBtInteractive : public BtInteractive {
 private:
-  int32_t cuid;
+  cuid_t cuid_;
 
-  SharedHandle<DownloadContext> _downloadContext;
+  SharedHandle<DownloadContext> downloadContext_;
 
-  SharedHandle<BtRuntime> _btRuntime;
+  SharedHandle<BtRuntime> btRuntime_;
 
-  SharedHandle<PieceStorage> _pieceStorage;
+  SharedHandle<PieceStorage> pieceStorage_;
 
-  SharedHandle<PeerStorage> _peerStorage;
+  SharedHandle<PeerStorage> peerStorage_;
 
-  SharedHandle<Peer> peer;
+  SharedHandle<Peer> peer_;
 
-  SharedHandle<BtMessageReceiver> btMessageReceiver;
-  SharedHandle<BtMessageDispatcher> dispatcher;
-  SharedHandle<BtRequestFactory> btRequestFactory;
-  SharedHandle<PeerConnection> peerConnection;
-  SharedHandle<BtMessageFactory> messageFactory;
-  SharedHandle<ExtensionMessageFactory> _extensionMessageFactory;
-  SharedHandle<ExtensionMessageRegistry> _extensionMessageRegistry;
-  SharedHandle<UTMetadataRequestFactory> _utMetadataRequestFactory;
-  SharedHandle<UTMetadataRequestTracker> _utMetadataRequestTracker;
+  SharedHandle<BtMessageReceiver> btMessageReceiver_;
+  SharedHandle<BtMessageDispatcher> dispatcher_;
+  SharedHandle<BtRequestFactory> btRequestFactory_;
+  // Although peerStorage_ is not used in this class, this object
+  // holds the reference so that peerConnection_ is not deleted.
+  SharedHandle<PeerConnection> peerConnection_;
+  SharedHandle<BtMessageFactory> messageFactory_;
+  SharedHandle<ExtensionMessageFactory> extensionMessageFactory_;
+  SharedHandle<ExtensionMessageRegistry> extensionMessageRegistry_;
+  SharedHandle<UTMetadataRequestFactory> utMetadataRequestFactory_;
+  SharedHandle<UTMetadataRequestTracker> utMetadataRequestTracker_;
 
-  bool _metadataGetMode;
+  bool metadataGetMode_;
 
-  WeakHandle<DHTNode> _localNode;
+  WeakHandle<DHTNode> localNode_;
 
-  Logger* logger;
-  size_t allowedFastSetSize;
-  Time haveCheckPoint;
-  Time keepAliveCheckPoint;
-  Time floodingCheckPoint;
-  FloodingStat floodingStat;
-  Time inactiveCheckPoint;
-  Time _pexCheckPoint;
-  Time _perSecCheckPoint;
-  time_t keepAliveInterval;
-  bool _utPexEnabled;
-  bool _dhtEnabled;
+  Logger* logger_;
+  size_t allowedFastSetSize_;
+  Timer haveTimer_;
+  Timer keepAliveTimer_;
+  Timer floodingTimer_;
+  FloodingStat floodingStat_;
+  Timer inactiveTimer_;
+  Timer pexTimer_;
+  Timer perSecTimer_;
+  time_t keepAliveInterval_;
+  bool utPexEnabled_;
+  bool dhtEnabled_;
 
-  size_t _numReceivedMessage;
+  size_t numReceivedMessage_;
 
-  size_t _maxOutstandingRequest;
+  size_t maxOutstandingRequest_;
 
-  WeakHandle<RequestGroupMan> _requestGroupMan;
+  WeakHandle<RequestGroupMan> requestGroupMan_;
 
   static const time_t FLOODING_CHECK_INTERVAL = 5;
 
@@ -160,7 +163,7 @@ private:
 
 public:
   DefaultBtInteractive(const SharedHandle<DownloadContext>& downloadContext,
-		       const SharedHandle<Peer>& peer);
+                       const SharedHandle<Peer>& peer);
 
   virtual ~DefaultBtInteractive();
 
@@ -188,8 +191,9 @@ public:
 
   virtual size_t countOutstandingRequest();
 
-  void setCuid(int32_t cuid) {
-    this->cuid = cuid;
+  void setCuid(cuid_t cuid)
+  {
+    cuid_ = cuid;
   }
 
   void setBtRuntime(const SharedHandle<BtRuntime>& btRuntime);
@@ -216,23 +220,23 @@ public:
   void setExtensionMessageRegistry
   (const SharedHandle<ExtensionMessageRegistry>& registry)
   {
-    _extensionMessageRegistry = registry;
+    extensionMessageRegistry_ = registry;
   }
 
   void setKeepAliveInterval(time_t keepAliveInterval) {
-    this->keepAliveInterval = keepAliveInterval;
+    keepAliveInterval_ = keepAliveInterval;
   }
 
   void setUTPexEnabled(bool f)
   {
-    _utPexEnabled = f;
+    utPexEnabled_ = f;
   }
 
   void setLocalNode(const WeakHandle<DHTNode>& node);
 
   void setDHTEnabled(bool f)
   {
-    _dhtEnabled = f;
+    dhtEnabled_ = f;
   }
 
   void setRequestGroupMan(const WeakHandle<RequestGroupMan>& rgman);
@@ -240,18 +244,18 @@ public:
   void setUTMetadataRequestTracker
   (const SharedHandle<UTMetadataRequestTracker>& tracker)
   {
-    _utMetadataRequestTracker = tracker;
+    utMetadataRequestTracker_ = tracker;
   }
 
   void setUTMetadataRequestFactory
   (const SharedHandle<UTMetadataRequestFactory>& factory)
   {
-    _utMetadataRequestFactory = factory;
+    utMetadataRequestFactory_ = factory;
   }
 
   void enableMetadataGetMode()
   {
-    _metadataGetMode = true;
+    metadataGetMode_ = true;
   }
 };
 
