@@ -74,69 +74,73 @@ class DownloadEngine {
 private:
   void waitData();
 
-  std::string _sessionId;
+  std::string sessionId_;
 
-  SharedHandle<EventPoll> _eventPoll;
+  SharedHandle<EventPoll> eventPoll_;
 
-  Logger* logger;
+  Logger* logger_;
   
-  SharedHandle<StatCalc> _statCalc;
+  SharedHandle<StatCalc> statCalc_;
 
-  bool _haltRequested;
+  bool haltRequested_;
 
   class SocketPoolEntry {
   private:
-    SharedHandle<SocketCore> _socket;
+    SharedHandle<SocketCore> socket_;
 
-    std::map<std::string, std::string> _options;
+    std::map<std::string, std::string> options_;
 
-    time_t _timeout;
+    time_t timeout_;
 
-    Timer _registeredTime;
+    Timer registeredTime_;
   public:
     SocketPoolEntry(const SharedHandle<SocketCore>& socket,
                     const std::map<std::string, std::string>& option,
                     time_t timeout);
 
+    SocketPoolEntry(const SharedHandle<SocketCore>& socket,
+                    time_t timeout);
+
     ~SocketPoolEntry();
 
     bool isTimeout() const;
 
     const SharedHandle<SocketCore>& getSocket() const
     {
-      return _socket;
+      return socket_;
     }
 
     const std::map<std::string, std::string>& getOptions() const
     {
-      return _options;
+      return options_;
     }
   };
 
   // key = IP address:port, value = SocketPoolEntry
-  std::multimap<std::string, SocketPoolEntry> _socketPool;
+  std::multimap<std::string, SocketPoolEntry> socketPool_;
  
-  Timer _lastSocketPoolScan;
+  Timer lastSocketPoolScan_;
 
-  bool _noWait;
+  bool noWait_;
 
-  static const time_t DEFAULT_REFRESH_INTERVAL = 1;
+  static const int64_t DEFAULT_REFRESH_INTERVAL = 900;
 
-  time_t _refreshInterval;
+  // Milliseconds
+  int64_t refreshInterval_;
 
-  std::deque<Command*> _routineCommands;
+  std::deque<Command*> routineCommands_;
 
-  SharedHandle<CookieStorage> _cookieStorage;
+  SharedHandle<CookieStorage> cookieStorage_;
 
 #ifdef ENABLE_BITTORRENT
-  SharedHandle<BtRegistry> _btRegistry;
+  SharedHandle<BtRegistry> btRegistry_;
 #endif // ENABLE_BITTORRENT
 
-  CUIDCounter _cuidCounter;
+  CUIDCounter cuidCounter_;
 
-  SharedHandle<DNSCache> _dnsCache;
+  SharedHandle<DNSCache> dnsCache_;
 
-  SharedHandle<AuthConfigFactory> _authConfigFactory;
+  SharedHandle<AuthConfigFactory> authConfigFactory_;
 
   /**
    * Delegates to StatCalc
@@ -147,22 +151,20 @@ private:
 
   void afterEachIteration();
   
-  void poolSocket(const std::string& ipaddr,
-                  uint16_t port,
-                  const SocketPoolEntry& entry);
+  void poolSocket(const std::string& key, const SocketPoolEntry& entry);
 
   std::multimap<std::string, SocketPoolEntry>::iterator
-  findSocketPoolEntry(const std::string& ipaddr, uint16_t port);
-public:
-  std::deque<Command*> commands;
-  SharedHandle<RequestGroupMan> _requestGroupMan;
-  SharedHandle<FileAllocationMan> _fileAllocationMan;
-  SharedHandle<CheckIntegrityMan> _checkIntegrityMan;
-  Option* option;
-  
+  findSocketPoolEntry(const std::string& key);
+
+  std::deque<Command*> commands_;
+  SharedHandle<RequestGroupMan> requestGroupMan_;
+  SharedHandle<FileAllocationMan> fileAllocationMan_;
+  SharedHandle<CheckIntegrityMan> checkIntegrityMan_;
+  Option* option_;
+public:  
   DownloadEngine(const SharedHandle<EventPoll>& eventPoll);
 
-  virtual ~DownloadEngine();
+  ~DownloadEngine();
 
   void run();
 
@@ -185,13 +187,61 @@ public:
                                Command* command);
 #endif // ENABLE_ASYNC_DNS
 
-  void addCommand(const std::vector<Command*>& commands);
+  void addCommand(const std::vector<Command*>& commands)
+  {
+    commands_.insert(commands_.end(), commands.begin(), commands.end());
+  }
+
+  void addCommand(Command* command)
+  {
+    commands_.push_back(command);
+  }
+
+  const SharedHandle<RequestGroupMan>& getRequestGroupMan() const
+  {
+    return requestGroupMan_;
+  }
+
+  void setRequestGroupMan(const SharedHandle<RequestGroupMan>& rgman)
+  {
+    requestGroupMan_ = rgman;
+  }
+
+  const SharedHandle<FileAllocationMan>& getFileAllocationMan() const
+  {
+    return fileAllocationMan_;
+  }
+
+  void setFileAllocationMan(const SharedHandle<FileAllocationMan>& faman)
+  {
+    fileAllocationMan_ = faman;
+  }
+
+  const SharedHandle<CheckIntegrityMan>& getCheckIntegrityMan() const
+  {
+    return checkIntegrityMan_;
+  }
+
+  void setCheckIntegrityMan(const SharedHandle<CheckIntegrityMan>& ciman)
+  {
+    checkIntegrityMan_ = ciman;
+  }
+
+  Option* getOption() const
+  {
+    return option_;
+  }
+
+  void setOption(Option* op)
+  {
+    option_ = op;
+  }
 
   void setStatCalc(const SharedHandle<StatCalc>& statCalc);
 
   bool isHaltRequested() const
   {
-    return _haltRequested;
+    return haltRequested_;
   }
 
   void requestHalt();
@@ -203,51 +253,61 @@ public:
   void addRoutineCommand(Command* command);
 
   void poolSocket(const std::string& ipaddr, uint16_t port,
+                  const std::string& username,
+                  const std::string& proxyhost, uint16_t proxyport,
                   const SharedHandle<SocketCore>& sock,
                   const std::map<std::string, std::string>& options,
                   time_t timeout = 15);
 
-  void poolSocket(const std::string& ipaddr, uint16_t port,
-                  const SharedHandle<SocketCore>& sock,
-                  time_t timeout = 15);
-  
   void poolSocket(const SharedHandle<Request>& request,
-                  bool proxyDefined,
+                  const std::string& username,
+                  const SharedHandle<Request>& proxyRequest,
                   const SharedHandle<SocketCore>& socket,
                   const std::map<std::string, std::string>& options,
                   time_t timeout = 15);
     
+  void poolSocket(const std::string& ipaddr, uint16_t port,
+                  const std::string& proxyhost, uint16_t proxyport,
+                  const SharedHandle<SocketCore>& sock,
+                  time_t timeout = 15);
+
   void poolSocket(const SharedHandle<Request>& request,
-                  bool proxyDefined,
+                  const SharedHandle<Request>& proxyRequest,
                   const SharedHandle<SocketCore>& socket,
                   time_t timeout = 15);
 
-  SharedHandle<SocketCore> popPooledSocket(const std::string& ipaddr,
-                                           uint16_t port);
+  SharedHandle<SocketCore> popPooledSocket
+  (const std::string& ipaddr,
+   uint16_t port,
+   const std::string& proxyhost, uint16_t proxyport);
 
   SharedHandle<SocketCore> popPooledSocket
   (std::map<std::string, std::string>& options,
    const std::string& ipaddr,
-   uint16_t port);
+   uint16_t port,
+   const std::string& username,
+   const std::string& proxyhost, uint16_t proxyport);
 
   SharedHandle<SocketCore>
-  popPooledSocket(const std::vector<std::string>& ipaddrs, uint16_t port);
+  popPooledSocket
+  (const std::vector<std::string>& ipaddrs, uint16_t port);
 
   SharedHandle<SocketCore>
   popPooledSocket
   (std::map<std::string, std::string>& options,
    const std::vector<std::string>& ipaddrs,
-   uint16_t port);
+   uint16_t port,
+   const std::string& username);
 
   const SharedHandle<CookieStorage>& getCookieStorage() const
   {
-    return _cookieStorage;
+    return cookieStorage_;
   }
 
 #ifdef ENABLE_BITTORRENT
   const SharedHandle<BtRegistry>& getBtRegistry() const
   {
-    return _btRegistry;
+    return btRegistry_;
   }
 #endif // ENABLE_BITTORRENT
 
@@ -260,7 +320,7 @@ public:
   void findAllCachedIPAddresses
   (OutputIterator out, const std::string& hostname, uint16_t port) const
   {
-    _dnsCache->findAll(out, hostname, port);
+    dnsCache_->findAll(out, hostname, port);
   }
 
   void cacheIPAddress
@@ -275,14 +335,14 @@ public:
 
   const SharedHandle<AuthConfigFactory>& getAuthConfigFactory() const
   {
-    return _authConfigFactory;
+    return authConfigFactory_;
   }
 
-  void setRefreshInterval(time_t interval);
+  void setRefreshInterval(int64_t interval);
 
   const std::string getSessionId() const
   {
-    return _sessionId;
+    return sessionId_;
   }
 };
 
