@@ -71,6 +71,8 @@
 #include "CheckIntegrityEntry.h"
 #include "Segment.h"
 #include "DlAbortEx.h"
+#include "uri.h"
+#include "Triplet.h"
 
 namespace aria2 {
 
@@ -87,7 +89,10 @@ RequestGroupMan::RequestGroupMan
   (option->getAsInt(PREF_MAX_OVERALL_DOWNLOAD_LIMIT)),
   maxOverallUploadSpeedLimit_(option->getAsInt(PREF_MAX_OVERALL_UPLOAD_LIMIT)),
   xmlRpc_(option->getAsBool(PREF_ENABLE_XML_RPC)),
-  queueCheck_(true)
+  queueCheck_(true),
+  removedErrorResult_(0),
+  removedLastErrorResult_(downloadresultcode::FINISHED),
+  maxDownloadResult_(option->getAsInt(PREF_MAX_DOWNLOAD_RESULT))
 {}
 
 bool RequestGroupMan::downloadFinished()
@@ -250,74 +255,24 @@ bool RequestGroupMan::removeReservedGroup(gid_t gid)
   }
 }
 
-static void executeHook(const std::string& command, gid_t gid)
-{
-  LogFactory::getInstance()->info("Executing user command: %s %s",
-                                  command.c_str(), util::itos(gid).c_str());
-#ifndef __MINGW32__
-  pid_t cpid = fork();
-  if(cpid == -1) {
-    LogFactory::getInstance()->error("fork() failed."
-                                     " Cannot execute user command.");
-  } else if(cpid == 0) {
-    execl(command.c_str(), command.c_str(), util::itos(gid).c_str(),
-          reinterpret_cast<char*>(0));
-    perror(("Could not execute user command: "+command).c_str());
-    exit(EXIT_FAILURE);
-  }
-#else
-  PROCESS_INFORMATION pi;
-  STARTUPINFO si;
-
-  memset(&si, 0, sizeof (si));
-  si.cb = sizeof(STARTUPINFO);
-
-  memset(&pi, 0, sizeof (pi));
-
-  std::string cmdline = command;
-  strappend(cmdline, " ", util::itos(gid));
-
-  DWORD rc = CreateProcess(
-                           NULL,
-                           (LPSTR)cmdline.c_str(),
-                           NULL,
-                           NULL,
-                           true,
-                           NULL,
-                           NULL,
-                           0,
-                           &si,
-                           &pi);
-
-  if(!rc)
-    LogFactory::getInstance()->error("CreateProcess() failed."
-                                     " Cannot execute user command.");
-#endif 
-}
-
-static void executeHookByOptName
-(const SharedHandle<RequestGroup>& group, const Option* option,
- const std::string& opt)
-{
-  if(!option->blank(opt)) {
-    executeHook(option->get(opt), group->getGID());
-  }
-}
-
 static void executeStopHook
 (const SharedHandle<DownloadResult>& result, const Option* option)
 {
   if(result->result == downloadresultcode::FINISHED &&
      !option->blank(PREF_ON_DOWNLOAD_COMPLETE)) {
-    executeHook(option->get(PREF_ON_DOWNLOAD_COMPLETE), result->gid);
+    util::executeHook(option->get(PREF_ON_DOWNLOAD_COMPLETE),
+                      util::itos(result->gid));
   } else if(result->result != downloadresultcode::IN_PROGRESS &&
             !option->blank(PREF_ON_DOWNLOAD_ERROR)) {
-    executeHook(option->get(PREF_ON_DOWNLOAD_ERROR), result->gid);
+    util::executeHook(option->get(PREF_ON_DOWNLOAD_ERROR),
+                      util::itos(result->gid));
   } else if(!option->blank(PREF_ON_DOWNLOAD_STOP)) {
-    executeHook(option->get(PREF_ON_DOWNLOAD_STOP), result->gid);
+    util::executeHook(option->get(PREF_ON_DOWNLOAD_STOP),
+                      util::itos(result->gid));
   }
 }
 
+namespace {
 class ProcessStoppedRequestGroup {
 private:
   DownloadEngine* e_;
@@ -387,6 +342,9 @@ public:
             e_->getRequestGroupMan()->insertReservedGroup(0, nextGroups);
           }
         } else {
+          logger_->notice("Download GID#%s not complete: %s",
+                          util::itos(group->getGID()).c_str(),
+                          group->getDownloadContext()->getBasePath().c_str());
           group->saveControlFile();
         }
       } catch(RecoverableException& ex) {
@@ -394,22 +352,24 @@ public:
       }
       if(group->isPauseRequested()) {
         reservedGroups_.push_front(group);
-      } else {
-        downloadResults_.push_back(group->createDownloadResult());
-      }
-      group->releaseRuntimeResource(e_);
-      if(group->isPauseRequested()) {
+        group->releaseRuntimeResource(e_);
         group->setForceHaltRequested(false);
-        executeHookByOptName(group, e_->getOption(), PREF_ON_DOWNLOAD_PAUSE);
+        util::executeHookByOptName
+          (group, e_->getOption(), PREF_ON_DOWNLOAD_PAUSE);
         // TODO Should we have to prepend spend uris to remaining uris
         // in case PREF_REUSE_URI is disabed?
       } else {
-        executeStopHook(downloadResults_.back(), e_->getOption());
+        SharedHandle<DownloadResult> dr = group->createDownloadResult();
+        e_->getRequestGroupMan()->addDownloadResult(dr);
+        group->releaseRuntimeResource(e_);
+        executeStopHook(dr, e_->getOption());
       }
     }
   }
 };
+}
 
+namespace {
 class CollectServerStat {
 private:
   RequestGroupMan* requestGroupMan_;
@@ -451,13 +411,16 @@ public:
     }    
   }
 };
+}
 
+namespace {
 class FindStoppedRequestGroup {
 public:
   bool operator()(const SharedHandle<RequestGroup>& group) {
     return group->getNumCommand() == 0;
   }
 };
+}
 
 void RequestGroupMan::updateServerStat()
 {
@@ -546,7 +509,8 @@ void RequestGroupMan::fillRequestGroupFromReserver(DownloadEngine* e)
       ++count;
       e->addCommand(commands);
       commands.clear();
-      executeHookByOptName(groupToAdd, e->getOption(), PREF_ON_DOWNLOAD_START);
+      util::executeHookByOptName
+        (groupToAdd, e->getOption(), PREF_ON_DOWNLOAD_START);
     } catch(RecoverableException& ex) {
       logger_->error(EX_EXCEPTION_CAUGHT, ex);
       if(logger_->debug()) {
@@ -558,7 +522,7 @@ void RequestGroupMan::fillRequestGroupFromReserver(DownloadEngine* e)
         logger_->debug("Commands deleted");
       }
       groupToAdd->releaseRuntimeResource(e);
-      downloadResults_.push_back(groupToAdd->createDownloadResult());
+      addDownloadResult(groupToAdd->createDownloadResult());
     }
   }
   if(!temp.empty()) {
@@ -600,9 +564,9 @@ void RequestGroupMan::closeFile()
 RequestGroupMan::DownloadStat RequestGroupMan::getDownloadStat() const
 {
   size_t finished = 0;
-  size_t error = 0;
+  size_t error = removedErrorResult_;
   size_t inprogress = 0;
-  downloadresultcode::RESULT lastError = downloadresultcode::FINISHED;
+  downloadresultcode::RESULT lastError = removedLastErrorResult_;
   for(std::deque<SharedHandle<DownloadResult> >::const_iterator itr =
         downloadResults_.begin(), eoi = downloadResults_.end();
       itr != eoi; ++itr) {
@@ -809,6 +773,42 @@ RequestGroupMan::findDownloadResult(gid_t gid) const
   return SharedHandle<DownloadResult>();
 }
 
+void RequestGroupMan::addDownloadResult(const SharedHandle<DownloadResult>& dr)
+{
+  if(maxDownloadResult_ == 0) {
+    if(!downloadResults_.empty()) {
+      for(std::deque<SharedHandle<DownloadResult> >::iterator i =
+            downloadResults_.begin(), eoi = downloadResults_.end(); i != eoi;
+          ++i) {
+        if((*i)->result != downloadresultcode::FINISHED) {
+          removedLastErrorResult_ = (*i)->result;
+          ++removedErrorResult_;
+        }
+      }
+      downloadResults_.clear();
+    }
+    if(dr->result != downloadresultcode::FINISHED) {
+      removedLastErrorResult_ = dr->result;
+      ++removedErrorResult_;
+    }
+  } else {
+    size_t curSize = downloadResults_.size();
+    if(curSize >= maxDownloadResult_) {
+      std::deque<SharedHandle<DownloadResult> >::iterator last =
+        downloadResults_.begin()+curSize-maxDownloadResult_+1;
+      for(std::deque<SharedHandle<DownloadResult> >::iterator i =
+            downloadResults_.begin(); i != last; ++i) {
+        if((*i)->result != downloadresultcode::FINISHED) {
+          removedLastErrorResult_ = (*i)->result;
+          ++removedErrorResult_;
+        }
+      }        
+      downloadResults_.erase(downloadResults_.begin(), last);
+    }
+    downloadResults_.push_back(dr);
+  }
+}
+
 void RequestGroupMan::purgeDownloadResult()
 {
   downloadResults_.clear();
@@ -896,4 +896,43 @@ bool RequestGroupMan::doesOverallUploadSpeedExceed()
     maxOverallUploadSpeedLimit_ < calculateStat().getUploadSpeed();
 }
 
+void RequestGroupMan::getUsedHosts
+(std::vector<std::pair<size_t, std::string> >& usedHosts)
+{
+  // vector of triplet which consists of use count, -download speed,
+  // hostname. We want to sort by least used and faster download
+  // speed. We use -download speed so that we can sort them using
+  // operator<().
+  std::vector<Triplet<size_t, int, std::string> > tempHosts;
+  for(std::deque<SharedHandle<RequestGroup> >::const_iterator i =
+        requestGroups_.begin(), eoi = requestGroups_.end(); i != eoi; ++i) {
+    const std::deque<SharedHandle<Request> >& inFlightReqs =
+      (*i)->getDownloadContext()->getFirstFileEntry()->getInFlightRequests();
+    for(std::deque<SharedHandle<Request> >::const_iterator j =
+          inFlightReqs.begin(), eoj = inFlightReqs.end(); j != eoj; ++j) {
+      uri::UriStruct us;
+      if(uri::parse(us, (*j)->getUri())) {
+        std::vector<Triplet<size_t, int, std::string> >::iterator k;
+        std::vector<Triplet<size_t, int, std::string> >::iterator eok =
+          tempHosts.end();
+        for(k =  tempHosts.begin(); k != eok; ++k) {
+          if((*k).third == us.host) {
+            ++(*k).first;
+            break;
+          }
+        }
+        if(k == eok) {
+          SharedHandle<ServerStat> ss = findServerStat(us.host, us.protocol);
+          int invDlSpeed = !ss.isNull() && ss->isOK()?
+            -(static_cast<int>(ss->getDownloadSpeed())):0;
+          tempHosts.push_back(makeTriplet(1, invDlSpeed, us.host));
+        }
+      }
+    }
+  }
+  std::sort(tempHosts.begin(), tempHosts.end());
+  std::transform(tempHosts.begin(), tempHosts.end(),
+                 std::back_inserter(usedHosts), Tuple2Pair<1, 3>());
+}
+
 } // namespace aria2
