@@ -41,19 +41,37 @@
 #include <deque>
 #include <algorithm>
 
-#include "BDE.h"
 #include "XmlRpcRequest.h"
+#include "ValueBase.h"
+#include "TorrentAttribute.h"
+#include "DlAbortEx.h"
 
 namespace aria2 {
 
-class DownloadResult;
+struct DownloadResult;
 class RequestGroup;
 
 namespace xmlrpc {
 
+template<typename OutputIterator>
+void toStringList(OutputIterator out, const List* src)
+{
+  if(!src) {
+    return;
+  }
+  for(List::ValueType::const_iterator i = src->begin(), eoi = src->end();
+      i != eoi; ++i) {
+    const String* s = asString(*i);
+    if(s) {
+      *out++ = s->s();
+    }
+  }
+}
+
 class AddUriXmlRpcMethod:public XmlRpcMethod {
 protected:
-  virtual BDE process(const XmlRpcRequest& req, DownloadEngine* e);
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e);
 public:
   static const std::string& getMethodName()
   {
@@ -64,7 +82,8 @@ public:
 
 class RemoveXmlRpcMethod:public XmlRpcMethod {
 protected:
-  virtual BDE process(const XmlRpcRequest& req, DownloadEngine* e);
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e);
 public:
   static const std::string& getMethodName()
   {
@@ -75,7 +94,8 @@ public:
 
 class ForceRemoveXmlRpcMethod:public XmlRpcMethod {
 protected:
-  virtual BDE process(const XmlRpcRequest& req, DownloadEngine* e);
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e);
 public:
   static const std::string& getMethodName()
   {
@@ -84,10 +104,83 @@ public:
   }
 };
 
+class PauseXmlRpcMethod:public XmlRpcMethod {
+protected:
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e);
+public:
+  static const std::string& getMethodName()
+  {
+    static std::string methodName = "aria2.pause";
+    return methodName;
+  }
+};
+
+class ForcePauseXmlRpcMethod:public XmlRpcMethod {
+protected:
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e);
+public:
+  static const std::string& getMethodName()
+  {
+    static std::string methodName = "aria2.forcePause";
+    return methodName;
+  }
+};
+
+class PauseAllXmlRpcMethod:public XmlRpcMethod {
+protected:
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e);
+public:
+  static const std::string& getMethodName()
+  {
+    static std::string methodName = "aria2.pauseAll";
+    return methodName;
+  }
+};
+
+class ForcePauseAllXmlRpcMethod:public XmlRpcMethod {
+protected:
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e);
+public:
+  static const std::string& getMethodName()
+  {
+    static std::string methodName = "aria2.forcePauseAll";
+    return methodName;
+  }
+};
+
+class UnpauseXmlRpcMethod:public XmlRpcMethod {
+protected:
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e);
+public:
+  static const std::string& getMethodName()
+  {
+    static std::string methodName = "aria2.unpause";
+    return methodName;
+  }
+};
+
+class UnpauseAllXmlRpcMethod:public XmlRpcMethod {
+protected:
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e);
+public:
+  static const std::string& getMethodName()
+  {
+    static std::string methodName = "aria2.unpauseAll";
+    return methodName;
+  }
+};
+
 #ifdef ENABLE_BITTORRENT
 class AddTorrentXmlRpcMethod:public XmlRpcMethod {
 protected:
-  virtual BDE process(const XmlRpcRequest& req, DownloadEngine* e);
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e);
 public:
   static const std::string& getMethodName()
   {
@@ -100,7 +193,8 @@ public:
 #ifdef ENABLE_METALINK
 class AddMetalinkXmlRpcMethod:public XmlRpcMethod {
 protected:
-  virtual BDE process(const XmlRpcRequest& req, DownloadEngine* e);
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e);
 public:
   static const std::string& getMethodName()
   {
@@ -112,7 +206,8 @@ public:
 
 class PurgeDownloadResultXmlRpcMethod:public XmlRpcMethod {
 protected:
-  virtual BDE process(const XmlRpcRequest& req, DownloadEngine* e);
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e);
 public:
   static const std::string& getMethodName()
   {
@@ -123,7 +218,8 @@ public:
 
 class GetUrisXmlRpcMethod:public XmlRpcMethod {
 protected:
-  virtual BDE process(const XmlRpcRequest& req, DownloadEngine* e);
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e);
 public:
   static const std::string& getMethodName()
   {
@@ -134,7 +230,8 @@ public:
 
 class GetFilesXmlRpcMethod:public XmlRpcMethod {
 protected:
-  virtual BDE process(const XmlRpcRequest& req, DownloadEngine* e);
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e);
 public:
   static const std::string& getMethodName()
   {
@@ -146,7 +243,8 @@ public:
 #ifdef ENABLE_BITTORRENT
 class GetPeersXmlRpcMethod:public XmlRpcMethod {
 protected:
-  virtual BDE process(const XmlRpcRequest& req, DownloadEngine* e);
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e);
 public:
   static const std::string& getMethodName()
   {
@@ -158,7 +256,8 @@ public:
 
 class GetServersXmlRpcMethod:public XmlRpcMethod {
 protected:
-  virtual BDE process(const XmlRpcRequest& req, DownloadEngine* e);
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e);
 public:
   static const std::string& getMethodName()
   {
@@ -169,7 +268,8 @@ public:
 
 class TellStatusXmlRpcMethod:public XmlRpcMethod {
 protected:
-  virtual BDE process(const XmlRpcRequest& req, DownloadEngine* e);
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e);
 public:
   static const std::string& getMethodName()
   {
@@ -180,7 +280,8 @@ public:
 
 class TellActiveXmlRpcMethod:public XmlRpcMethod {
 protected:
-  virtual BDE process(const XmlRpcRequest& req, DownloadEngine* e);
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e);
 public:
   static const std::string& getMethodName()
   {
@@ -211,7 +312,6 @@ private:
     } else if(size <= (size_t)offset) {
       return std::make_pair(last, last);
     }
-    BDE list = BDE::list();
     size_t lastDistance;
     if(size < offset+num) {
       lastDistance = size;
@@ -224,34 +324,40 @@ private:
     return std::make_pair(first, last);
   }
 
-  void checkPaginationParams(const BDE& params) const
+  void checkPaginationParams(const SharedHandle<List>& params) const
   {
-    assert(params.isList());
-    if(params.size() != 2 ||
-       !params[0].isInteger() || !params[1].isInteger() ||
-       params[1].i() < 0) {
+    if(params->size() < 2) {
+      throw DL_ABORT_EX("Invalid argument. Specify offset and num in integer.");
+    }
+    const Integer* p1 = asInteger(params->get(0));
+    const Integer* p2 = asInteger(params->get(1));
+    if(!p1 || !p2 || p2->i() < 0) {
       throw DL_ABORT_EX("Invalid argument. Specify offset and num in integer.");
     }
   }
 protected:
-  virtual BDE process(const XmlRpcRequest& req, DownloadEngine* e)
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e)
   {
-    const BDE& params = req._params;
+    const SharedHandle<List>& params = req.params;
     checkPaginationParams(params);
-    ssize_t offset = params[0].i();
-    size_t num = params[1].i();
+    ssize_t offset = req.getIntegerParam(0)->i();
+    size_t num = req.getIntegerParam(1)->i();
+    const List* keysParam = req.getListParam(2);
+    std::vector<std::string> keys;
+    toStringList(std::back_inserter(keys), keysParam);
     const std::deque<SharedHandle<T> >& items = getItems(e);
     std::pair<typename std::deque<SharedHandle<T> >::const_iterator,
       typename std::deque<SharedHandle<T> >::const_iterator> range =
       getPaginationRange(offset, num, items.begin(), items.end());
-    BDE list = BDE::list();
+    SharedHandle<List> list = List::g();
     for(; range.first != range.second; ++range.first) {
-      BDE entryDict = BDE::dict();
-      createEntry(entryDict, *range.first, e);
-      list << entryDict;
+      SharedHandle<Dict> entryDict = Dict::g();
+      createEntry(entryDict, *range.first, e, keys);
+      list->append(entryDict);
     }
     if(offset < 0) {
-      std::reverse(list.listBegin(), list.listEnd());
+      std::reverse(list->begin(), list->end());
     }
     return list;
   }
@@ -260,7 +366,10 @@ protected:
   getItems(DownloadEngine* e) const = 0;
 
   virtual void createEntry
-  (BDE& entryDict, const SharedHandle<T>& item, DownloadEngine* e) const = 0;
+  (const SharedHandle<Dict>& entryDict,
+   const SharedHandle<T>& item,
+   DownloadEngine* e,
+   const std::vector<std::string>& keys) const = 0;
 };
 
 class TellWaitingXmlRpcMethod:
@@ -270,8 +379,10 @@ protected:
   getItems(DownloadEngine* e) const;
 
   virtual void createEntry
-  (BDE& entryDict, const SharedHandle<RequestGroup>& item,
-   DownloadEngine* e) const;
+  (const SharedHandle<Dict>& entryDict,
+   const SharedHandle<RequestGroup>& item,
+   DownloadEngine* e,
+   const std::vector<std::string>& keys) const;
 public:
   static const std::string& getMethodName()
   {
@@ -287,8 +398,10 @@ protected:
    getItems(DownloadEngine* e) const;
 
   virtual void createEntry
-  (BDE& entryDict, const SharedHandle<DownloadResult>& item,
-   DownloadEngine* e) const;
+  (const SharedHandle<Dict>& entryDict,
+   const SharedHandle<DownloadResult>& item,
+   DownloadEngine* e,
+   const std::vector<std::string>& keys) const;
 public:
   static const std::string& getMethodName()
   {
@@ -299,7 +412,8 @@ public:
 
 class ChangeOptionXmlRpcMethod:public XmlRpcMethod {
 protected:
-  virtual BDE process(const XmlRpcRequest& req, DownloadEngine* e);
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e);
 public:
   static const std::string& getMethodName()
   {
@@ -310,7 +424,8 @@ public:
 
 class ChangeGlobalOptionXmlRpcMethod:public XmlRpcMethod {
 protected:
-  virtual BDE process(const XmlRpcRequest& req, DownloadEngine* e);
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e);
 public:
   static const std::string& getMethodName()
   {
@@ -321,7 +436,8 @@ public:
 
 class GetVersionXmlRpcMethod:public XmlRpcMethod {
 protected:
-  virtual BDE process(const XmlRpcRequest& req, DownloadEngine* e);
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e);
 public:
   static const std::string& getMethodName()
   {
@@ -332,7 +448,8 @@ public:
 
 class GetOptionXmlRpcMethod:public XmlRpcMethod {
 protected:
-  virtual BDE process(const XmlRpcRequest& req, DownloadEngine* e);
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e);
 public:
   static const std::string& getMethodName()
   {
@@ -343,7 +460,8 @@ public:
 
 class GetGlobalOptionXmlRpcMethod:public XmlRpcMethod {
 protected:
-  virtual BDE process(const XmlRpcRequest& req, DownloadEngine* e);
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e);
 public:
   static const std::string& getMethodName()
   {
@@ -354,7 +472,8 @@ public:
 
 class ChangePositionXmlRpcMethod:public XmlRpcMethod {
 protected:
-  virtual BDE process(const XmlRpcRequest& req, DownloadEngine* e);
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e);
 public:
   static const std::string& getMethodName()
   {
@@ -365,7 +484,8 @@ public:
 
 class ChangeUriXmlRpcMethod:public XmlRpcMethod {
 protected:
-  virtual BDE process(const XmlRpcRequest& req, DownloadEngine* e);
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e);
 public:
   static const std::string& getMethodName()
   {
@@ -376,7 +496,8 @@ public:
 
 class GetSessionInfoXmlRpcMethod:public XmlRpcMethod {
 protected:
-  virtual BDE process(const XmlRpcRequest& req, DownloadEngine* e);
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e);
 public:
   static const std::string& getMethodName()
   {
@@ -385,9 +506,34 @@ public:
   }
 };
 
+class ShutdownXmlRpcMethod:public XmlRpcMethod {
+protected:
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e);
+public:
+  static const std::string& getMethodName()
+  {
+    static std::string methodName = "aria2.shutdown";
+    return methodName;
+  }
+};
+
+class ForceShutdownXmlRpcMethod:public XmlRpcMethod {
+protected:
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e);
+public:
+  static const std::string& getMethodName()
+  {
+    static std::string methodName = "aria2.forceShutdown";
+    return methodName;
+  }
+};
+
 class SystemMulticallXmlRpcMethod:public XmlRpcMethod {
 protected:
-  virtual BDE process(const XmlRpcRequest& req, DownloadEngine* e);
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e);
 public:
   static const std::string& getMethodName()
   {
@@ -398,23 +544,27 @@ public:
 
 class NoSuchMethodXmlRpcMethod:public XmlRpcMethod {
 protected:
-  virtual BDE process(const XmlRpcRequest& req, DownloadEngine* e);
+  virtual SharedHandle<ValueBase> process
+  (const XmlRpcRequest& req, DownloadEngine* e);
 };
 
 // Helper function to store data to entryDict from ds. This function
 // is used by tellStatus method.
 void gatherStoppedDownload
-(BDE& entryDict, const SharedHandle<DownloadResult>& ds);
+(const SharedHandle<Dict>& entryDict, const SharedHandle<DownloadResult>& ds,
+ const std::vector<std::string>& keys);
 
 // Helper function to store data to entryDict from group. This
 // function is used by tellStatus/tellActive/tellWaiting method
 void gatherProgressCommon
-(BDE& entryDict, const SharedHandle<RequestGroup>& group);
+(const SharedHandle<Dict>& entryDict, const SharedHandle<RequestGroup>& group,
+ const std::vector<std::string>& keys);
 
 #ifdef ENABLE_BITTORRENT
-// Helper function to store BitTorrent metadata from torrentAttrs in
-// btDict. btDict must be an BDE::Dict.
-void gatherBitTorrentMetadata(BDE& btDict, const BDE& torrentAttrs);
+// Helper function to store BitTorrent metadata from torrentAttrs.
+void gatherBitTorrentMetadata
+(const SharedHandle<Dict>& btDict,
+ const SharedHandle<TorrentAttribute>& torrentAttrs);
 #endif // ENABLE_BITTORRENT
 
 } // namespace xmlrpc
