@@ -52,6 +52,14 @@ struct XmlRpcRequest {
   XmlRpcRequest(const std::string& methodName,
                 const SharedHandle<List>& params):
     methodName(methodName), params(params) {}
+
+  const String* getStringParam(size_t index) const;
+
+  const Integer* getIntegerParam(size_t index) const;
+
+  const List* getListParam(size_t index) const;
+  
+  const Dict* getDictParam(size_t index) const;
 };
 
 } // namespace xmlrpc
