@@ -168,7 +168,8 @@
 #define MSG_LOADING_TRUSTED_CA_CERT_FAILED                              \
   _("Failed to load trusted CA certificates from %s. Cause: %s")
 #define MSG_CERT_VERIFICATION_FAILED                    \
-  _("Certificate verification failed. Cause: %s")
+  _("Certificate verification failed. Cause: %s See --ca-certificate and" \
+    " --check-certificate option.")
 #define MSG_NO_CERT_FOUND _("No certificate found.")
 #define MSG_HOSTNAME_NOT_MATCH _("Hostname not match.")
 #define MSG_NO_FILES_TO_DOWNLOAD _("No files to download.")
@@ -188,6 +189,8 @@
 #define MSG_METADATA_NOT_SAVED _("Saving metadata as %s failed. Maybe file" \
                                  " already exists.")
 #define MSG_DIR_TRAVERSAL_DETECTED _("Detected directory traversal directive in %s")
+#define MSG_HASH_CHECK_NOT_DONE                                         \
+  "File has already been downloaded but hash check has not been done yet."
 
 #define EX_TIME_OUT _("Timeout.")
 #define EX_INVALID_CHUNK_SIZE _("Invalid chunk size.")
