@@ -19,9 +19,9 @@ namespace aria2 {
 class UtilTest:public CppUnit::TestFixture {
 
   CPPUNIT_TEST_SUITE(UtilTest);
-  CPPUNIT_TEST(testTrim);
+  CPPUNIT_TEST(testStrip);
+  CPPUNIT_TEST(testDivide);
   CPPUNIT_TEST(testSplit);
-  CPPUNIT_TEST(testSplit_many);
   CPPUNIT_TEST(testEndsWith);
   CPPUNIT_TEST(testReplace);
   CPPUNIT_TEST(testStartsWith);
@@ -30,6 +30,8 @@ class UtilTest:public CppUnit::TestFixture {
   CPPUNIT_TEST(testRandomAlpha);
   CPPUNIT_TEST(testToUpper);
   CPPUNIT_TEST(testToLower);
+  CPPUNIT_TEST(testUppercase);
+  CPPUNIT_TEST(testLowercase);
   CPPUNIT_TEST(testPercentDecode);
   CPPUNIT_TEST(testGetRealSize);
   CPPUNIT_TEST(testAbbrevSize);
@@ -46,6 +48,8 @@ class UtilTest:public CppUnit::TestFixture {
   CPPUNIT_TEST(testParseUInt);
   CPPUNIT_TEST(testParseLLInt);
   CPPUNIT_TEST(testParseULLInt);
+  CPPUNIT_TEST(testParseUIntNoThrow);
+  CPPUNIT_TEST(testParseLLIntNoThrow);
   CPPUNIT_TEST(testToString_binaryStream);
   CPPUNIT_TEST(testItos);
   CPPUNIT_TEST(testUitos);
@@ -65,6 +69,7 @@ class UtilTest:public CppUnit::TestFixture {
   CPPUNIT_TEST(testEscapePath);
   CPPUNIT_TEST(testGetCidrPrefix);
   CPPUNIT_TEST(testInSameCidrBlock);
+  CPPUNIT_TEST(testIsUtf8String);
   CPPUNIT_TEST_SUITE_END();
 private:
 
@@ -72,9 +77,9 @@ public:
   void setUp() {
   }
 
-  void testTrim();
+  void testStrip();
+  void testDivide();
   void testSplit();
-  void testSplit_many();
   void testEndsWith();
   void testReplace();
   void testStartsWith();
@@ -83,6 +88,8 @@ public:
   void testRandomAlpha();
   void testToUpper();
   void testToLower();
+  void testUppercase();
+  void testLowercase();
   void testPercentDecode();
   void testGetRealSize();
   void testAbbrevSize();
@@ -99,6 +106,8 @@ public:
   void testParseUInt();
   void testParseLLInt();
   void testParseULLInt();
+  void testParseUIntNoThrow();
+  void testParseLLIntNoThrow();
   void testToString_binaryStream();
   void testItos();
   void testUitos();
@@ -118,85 +127,141 @@ public:
   void testEscapePath();
   void testGetCidrPrefix();
   void testInSameCidrBlock();
+  void testIsUtf8String();
 };
 
 
 CPPUNIT_TEST_SUITE_REGISTRATION( UtilTest );
 
-void UtilTest::testTrim() {
+void UtilTest::testStrip()
+{
   std::string str1 = "aria2";
-  CPPUNIT_ASSERT_EQUAL(str1, util::trim("aria2"));
-  CPPUNIT_ASSERT_EQUAL(str1, util::trim(" aria2"));
-  CPPUNIT_ASSERT_EQUAL(str1, util::trim(" aria2 "));
-  CPPUNIT_ASSERT_EQUAL(str1, util::trim("  aria2  "));
+  CPPUNIT_ASSERT_EQUAL(str1, util::strip("aria2"));
+  CPPUNIT_ASSERT_EQUAL(str1, util::strip(" aria2"));
+  CPPUNIT_ASSERT_EQUAL(str1, util::strip("aria2 "));
+  CPPUNIT_ASSERT_EQUAL(str1, util::strip(" aria2 "));
+  CPPUNIT_ASSERT_EQUAL(str1, util::strip("  aria2  "));
   std::string str2 = "aria2 debut";
-  CPPUNIT_ASSERT_EQUAL(str2, util::trim("aria2 debut"));
-  CPPUNIT_ASSERT_EQUAL(str2, util::trim(" aria2 debut "));
+  CPPUNIT_ASSERT_EQUAL(str2, util::strip("aria2 debut"));
+  CPPUNIT_ASSERT_EQUAL(str2, util::strip(" aria2 debut "));
   std::string str3 = "";
-  CPPUNIT_ASSERT_EQUAL(str3, util::trim(""));
-  CPPUNIT_ASSERT_EQUAL(str3, util::trim(" "));
-  CPPUNIT_ASSERT_EQUAL(str3, util::trim("  "));
+  CPPUNIT_ASSERT_EQUAL(str3, util::strip(""));
+  CPPUNIT_ASSERT_EQUAL(str3, util::strip(" "));
+  CPPUNIT_ASSERT_EQUAL(str3, util::strip("  "));
   std::string str4 = "A";
-  CPPUNIT_ASSERT_EQUAL(str4, util::trim("A"));
-  CPPUNIT_ASSERT_EQUAL(str4, util::trim(" A "));
-  CPPUNIT_ASSERT_EQUAL(str4, util::trim("  A  "));
+  CPPUNIT_ASSERT_EQUAL(str4, util::strip("A"));
+  CPPUNIT_ASSERT_EQUAL(str4, util::strip(" A "));
+  CPPUNIT_ASSERT_EQUAL(str4, util::strip("  A  "));
+}
+
+void UtilTest::testDivide() {
+  std::pair<std::string, std::string> p1;
+  util::divide(p1, "name=value", '=');
+  CPPUNIT_ASSERT_EQUAL(std::string("name"), p1.first);
+  CPPUNIT_ASSERT_EQUAL(std::string("value"), p1.second);
+  util::divide(p1, " name = value ", '=');
+  CPPUNIT_ASSERT_EQUAL(std::string("name"), p1.first);
+  CPPUNIT_ASSERT_EQUAL(std::string("value"), p1.second);
+  util::divide(p1, "=value", '=');
+  CPPUNIT_ASSERT_EQUAL(std::string(""), p1.first);
+  CPPUNIT_ASSERT_EQUAL(std::string("value"), p1.second);
+  util::divide(p1, "name=", '=');
+  CPPUNIT_ASSERT_EQUAL(std::string("name"), p1.first);
+  CPPUNIT_ASSERT_EQUAL(std::string(""), p1.second);
+  util::divide(p1, "name", '=');
+  CPPUNIT_ASSERT_EQUAL(std::string("name"), p1.first);
+  CPPUNIT_ASSERT_EQUAL(std::string(""), p1.second);
 }
 
 void UtilTest::testSplit() {
-  std::pair<std::string, std::string> p1;
-  util::split(p1, "name=value", '=');
-  CPPUNIT_ASSERT_EQUAL(std::string("name"), p1.first);
-  CPPUNIT_ASSERT_EQUAL(std::string("value"), p1.second);
-  util::split(p1, " name = value ", '=');
-  CPPUNIT_ASSERT_EQUAL(std::string("name"), p1.first);
-  CPPUNIT_ASSERT_EQUAL(std::string("value"), p1.second);
-  util::split(p1, "=value", '=');
-  CPPUNIT_ASSERT_EQUAL(std::string(""), p1.first);
-  CPPUNIT_ASSERT_EQUAL(std::string("value"), p1.second);
-  util::split(p1, "name=", '=');
-  CPPUNIT_ASSERT_EQUAL(std::string("name"), p1.first);
-  CPPUNIT_ASSERT_EQUAL(std::string(""), p1.second);
-  util::split(p1, "name", '=');
-  CPPUNIT_ASSERT_EQUAL(std::string("name"), p1.first);
-  CPPUNIT_ASSERT_EQUAL(std::string(""), p1.second);
-}
+  std::vector<std::string> v;
+  util::split("k1; k2;; k3", std::back_inserter(v), ";", true);
+  CPPUNIT_ASSERT_EQUAL((size_t)3, v.size());
+  std::vector<std::string>::iterator itr = v.begin();
+  CPPUNIT_ASSERT_EQUAL(std::string("k1"), *itr++);
+  CPPUNIT_ASSERT_EQUAL(std::string("k2"), *itr++);
+  CPPUNIT_ASSERT_EQUAL(std::string("k3"), *itr++);
 
-void UtilTest::testSplit_many() {
-  std::vector<std::string> v1;
-  util::split("name1=value1; name2=value2; name3=value3",std::back_inserter(v1),
-              ";", true);
-  CPPUNIT_ASSERT_EQUAL((size_t)3, v1.size());
-  std::vector<std::string>::iterator itr = v1.begin();
-  CPPUNIT_ASSERT_EQUAL(std::string("name1=value1"), *itr++);
-  CPPUNIT_ASSERT_EQUAL(std::string("name2=value2"), *itr++);
-  CPPUNIT_ASSERT_EQUAL(std::string("name3=value3"), *itr++);
+  v.clear();
 
-  v1.clear();
+  util::split("k1; k2; k3",
+              std::back_inserter(v), ";");
+  CPPUNIT_ASSERT_EQUAL((size_t)3, v.size());
+  itr = v.begin();
+  CPPUNIT_ASSERT_EQUAL(std::string("k1"), *itr++);
+  CPPUNIT_ASSERT_EQUAL(std::string(" k2"), *itr++);
+  CPPUNIT_ASSERT_EQUAL(std::string(" k3"), *itr++);
 
-  util::split("name1=value1; name2=value2; name3=value3",std::back_inserter(v1),
-              ";", false);
-  CPPUNIT_ASSERT_EQUAL((size_t)3, v1.size());
-  itr = v1.begin();
-  CPPUNIT_ASSERT_EQUAL(std::string("name1=value1"), *itr++);
-  CPPUNIT_ASSERT_EQUAL(std::string(" name2=value2"), *itr++);
-  CPPUNIT_ASSERT_EQUAL(std::string(" name3=value3"), *itr++);
+  v.clear();
 
-  v1.clear();
+  util::split("k=v", std::back_inserter(v), ";", false, true);
+  CPPUNIT_ASSERT_EQUAL((size_t)1, v.size());
+  itr = v.begin();
+  CPPUNIT_ASSERT_EQUAL(std::string("k=v"), *itr++);
 
-  util::split("k=v", std::back_inserter(v1), ";", false, true);
-  CPPUNIT_ASSERT_EQUAL((size_t)1, v1.size());
-  CPPUNIT_ASSERT_EQUAL(std::string("k=v"), v1[0]);
+  v.clear();
 
-  v1.clear();
+  util::split(";;k1;;k2;", std::back_inserter(v), ";", false, true);
+  CPPUNIT_ASSERT_EQUAL((size_t)6, v.size());
+  itr = v.begin();
+  CPPUNIT_ASSERT_EQUAL(std::string(""), *itr++);
+  CPPUNIT_ASSERT_EQUAL(std::string(""), *itr++);
+  CPPUNIT_ASSERT_EQUAL(std::string("k1"), *itr++);
+  CPPUNIT_ASSERT_EQUAL(std::string(""), *itr++);
+  CPPUNIT_ASSERT_EQUAL(std::string("k2"), *itr++);
+  CPPUNIT_ASSERT_EQUAL(std::string(""), *itr++);
 
-  util::split(" ", std::back_inserter(v1), ";", true, true);
-  CPPUNIT_ASSERT_EQUAL((size_t)1, v1.size());
-  CPPUNIT_ASSERT_EQUAL(std::string(""), v1[0]);
+  v.clear();
 
-  v1.clear();
+  util::split(";;k1;;k2;", std::back_inserter(v), ";");
+  CPPUNIT_ASSERT_EQUAL((size_t)2, v.size());
+  itr = v.begin();
+  CPPUNIT_ASSERT_EQUAL(std::string("k1"), *itr++);
+  CPPUNIT_ASSERT_EQUAL(std::string("k2"), *itr++);
 
-  util::split(" ", std::back_inserter(v1), ";", true);
-  CPPUNIT_ASSERT_EQUAL((size_t)0, v1.size());
+  v.clear();
+
+  util::split("k; ", std::back_inserter(v), ";");
+  CPPUNIT_ASSERT_EQUAL((size_t)2, v.size());
+  itr = v.begin();
+  CPPUNIT_ASSERT_EQUAL(std::string("k"), *itr++);
+  CPPUNIT_ASSERT_EQUAL(std::string(" "), *itr++);
+
+  v.clear();
+
+  util::split(" ", std::back_inserter(v), ";", true, true);
+  CPPUNIT_ASSERT_EQUAL((size_t)1, v.size());
+  CPPUNIT_ASSERT_EQUAL(std::string(""), v[0]);
+
+  v.clear();
+
+  util::split(" ", std::back_inserter(v), ";", true);
+  CPPUNIT_ASSERT_EQUAL((size_t)0, v.size());
+
+  v.clear();
+
+  util::split(" ", std::back_inserter(v), ";");
+  CPPUNIT_ASSERT_EQUAL((size_t)1, v.size());
+  CPPUNIT_ASSERT_EQUAL(std::string(" "), v[0]);
+
+  v.clear();
+
+  util::split(";", std::back_inserter(v), ";");
+  CPPUNIT_ASSERT_EQUAL((size_t)0, v.size());
+
+  v.clear();
+
+  util::split(";", std::back_inserter(v), ";", false, true);
+  CPPUNIT_ASSERT_EQUAL((size_t)2, v.size());
+  itr = v.begin();
+  CPPUNIT_ASSERT_EQUAL(std::string(""), *itr++);
+  CPPUNIT_ASSERT_EQUAL(std::string(""), *itr++);
+
+  v.clear();
+
+  util::split("", std::back_inserter(v), ";", false, true);
+  CPPUNIT_ASSERT_EQUAL((size_t)1, v.size());
+  CPPUNIT_ASSERT_EQUAL(std::string(""), v[0]);
 }
 
 void UtilTest::testEndsWith() {
@@ -430,6 +495,20 @@ void UtilTest::testToLower() {
   CPPUNIT_ASSERT_EQUAL(upp, util::toLower(src));
 }
 
+void UtilTest::testUppercase() {
+  std::string src = "608cabc0f2fa18c260cafd974516865c772363d5";
+  std::string ans = "608CABC0F2FA18C260CAFD974516865C772363D5";
+  util::uppercase(src);
+  CPPUNIT_ASSERT_EQUAL(ans, src);
+}
+
+void UtilTest::testLowercase() {
+  std::string src = "608CABC0F2FA18C260CAFD974516865C772363D5";
+  std::string ans = "608cabc0f2fa18c260cafd974516865c772363d5";
+  util::lowercase(src);
+  CPPUNIT_ASSERT_EQUAL(ans, src);
+}
+
 void UtilTest::testPercentDecode() {
   std::string src = "http://aria2.sourceforge.net/aria2%200.7.0%20docs.html";
   CPPUNIT_ASSERT_EQUAL(std::string("http://aria2.sourceforge.net/aria2 0.7.0 docs.html"),
@@ -749,6 +828,26 @@ void UtilTest::testParseULLInt()
   }
 }
 
+void UtilTest::testParseUIntNoThrow()
+{
+  uint32_t n;
+  CPPUNIT_ASSERT(util::parseUIntNoThrow(n, " 4294967295 "));
+  CPPUNIT_ASSERT_EQUAL((uint32_t)UINT32_MAX, n);
+  CPPUNIT_ASSERT(!util::parseUIntNoThrow(n, "4294967296"));
+  CPPUNIT_ASSERT(!util::parseUIntNoThrow(n, "-1"));
+}
+
+void UtilTest::testParseLLIntNoThrow()
+{
+  int64_t n;
+  CPPUNIT_ASSERT(util::parseLLIntNoThrow(n, " 9223372036854775807 "));
+  CPPUNIT_ASSERT_EQUAL((int64_t)INT64_MAX, n);
+  CPPUNIT_ASSERT(!util::parseLLIntNoThrow(n, "9223372036854775808"));
+  CPPUNIT_ASSERT(util::parseLLIntNoThrow(n, "-9223372036854775808"));
+  CPPUNIT_ASSERT_EQUAL((int64_t)INT64_MIN, n);
+  CPPUNIT_ASSERT(!util::parseLLIntNoThrow(n, "-9223372036854775809"));
+}
+
 void UtilTest::testToString_binaryStream()
 {
   SharedHandle<DiskWriter> dw(new ByteArrayDiskWriter());
@@ -1022,9 +1121,9 @@ void UtilTest::testApplyDir()
 
 void UtilTest::testFixTaintedBasename()
 {
-  CPPUNIT_ASSERT_EQUAL(std::string("a_b"), util::fixTaintedBasename("a/b"));
+  CPPUNIT_ASSERT_EQUAL(std::string("a%2Fb"), util::fixTaintedBasename("a/b"));
 #ifdef __MINGW32__
-  CPPUNIT_ASSERT_EQUAL(std::string("a_b"), util::fixTaintedBasename("a\\b"));
+  CPPUNIT_ASSERT_EQUAL(std::string("a%5Cb"), util::fixTaintedBasename("a\\b"));
 #else // !__MINGW32__
   CPPUNIT_ASSERT_EQUAL(std::string("a\\b"), util::fixTaintedBasename("a\\b"));
 #endif // !__MINGW32__
@@ -1057,12 +1156,12 @@ void UtilTest::testDetectDirTraversal()
 
 void UtilTest::testEscapePath()
 {
-  CPPUNIT_ASSERT_EQUAL(std::string("foo_bar__"),
+  CPPUNIT_ASSERT_EQUAL(std::string("foo%00bar%00%01"),
                        util::escapePath(std::string("foo")+(char)0x00+
                                         std::string("bar")+(char)0x00+
                                         (char)0x01));
 #ifdef __MINGW32__
-  CPPUNIT_ASSERT_EQUAL(std::string("foo_bar"), util::escapePath("foo\\bar"));
+  CPPUNIT_ASSERT_EQUAL(std::string("foo%5Cbar"), util::escapePath("foo\\bar"));
 #else // !__MINGW32__
   CPPUNIT_ASSERT_EQUAL(std::string("foo\\bar"), util::escapePath("foo\\bar"));
 #endif // !__MINGW32__
@@ -1098,4 +1197,36 @@ void UtilTest::testInSameCidrBlock()
   CPPUNIT_ASSERT(!util::inSameCidrBlock("192.168.128.1", "192.168.0.1", 17));
 }
 
+void UtilTest::testIsUtf8String()
+{
+  CPPUNIT_ASSERT(util::isUtf8("ascii"));
+  // "Hello World" in Japanese UTF-8
+  CPPUNIT_ASSERT(util::isUtf8
+                 (util::fromHex("e38193e38293e381abe381a1e381afe4b896e7958c")));
+  // "World" in Shift_JIS
+  CPPUNIT_ASSERT(!util::isUtf8(util::fromHex("90a28a")+"E"));
+  // UTF8-2
+  CPPUNIT_ASSERT(util::isUtf8(util::fromHex("c280")));
+  CPPUNIT_ASSERT(util::isUtf8(util::fromHex("dfbf")));
+  // UTF8-3
+  CPPUNIT_ASSERT(util::isUtf8(util::fromHex("e0a080")));
+  CPPUNIT_ASSERT(util::isUtf8(util::fromHex("e0bf80")));
+  CPPUNIT_ASSERT(util::isUtf8(util::fromHex("e18080")));
+  CPPUNIT_ASSERT(util::isUtf8(util::fromHex("ec8080")));
+  CPPUNIT_ASSERT(util::isUtf8(util::fromHex("ed8080")));
+  CPPUNIT_ASSERT(util::isUtf8(util::fromHex("ed9f80")));
+  CPPUNIT_ASSERT(util::isUtf8(util::fromHex("ee8080")));
+  CPPUNIT_ASSERT(util::isUtf8(util::fromHex("ef8080")));
+  // UTF8-4
+  CPPUNIT_ASSERT(util::isUtf8(util::fromHex("f0908080")));
+  CPPUNIT_ASSERT(util::isUtf8(util::fromHex("f0bf8080")));
+  CPPUNIT_ASSERT(util::isUtf8(util::fromHex("f1808080")));
+  CPPUNIT_ASSERT(util::isUtf8(util::fromHex("f3808080")));
+  CPPUNIT_ASSERT(util::isUtf8(util::fromHex("f4808080")));
+  CPPUNIT_ASSERT(util::isUtf8(util::fromHex("f48f8080")));
+
+  CPPUNIT_ASSERT(util::isUtf8(""));
+  CPPUNIT_ASSERT(!util::isUtf8(util::fromHex("00")));
+}
+
 } // namespace aria2
